@@ -1,8 +1,8 @@
 //                                               -*- C++ -*-
 /**
- *  @brief The class that implements numerical math functions
+ *  @brief The class that implements functions
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -270,6 +270,19 @@ Graph Evaluation::draw(const Point & xMin,
   return getImplementation()->draw(xMin, xMax, pointNumber, scale);
 }
 
+/** Draw cross sections of the function assumed to have 1D output */
+GridLayout Evaluation::drawCrossCuts(const Point & centralPoint,
+                                     const Point & xMin,
+                                     const Point & xMax,
+                                     const Indices & pointNumber,
+                                     const Bool withMonoDimensionalCuts,
+                                     const Bool isFilled,
+                                     const Scalar vMin,
+                                     const Scalar vMax) const
+{
+  return getImplementation()->drawCrossCuts(centralPoint, xMin, xMax, pointNumber, withMonoDimensionalCuts, isFilled, vMin, vMax);
+}
+
 void Evaluation::setStopCallback(StopCallback callBack, void * state)
 {
   copyOnWrite();
