@@ -2,7 +2,7 @@
 /**
  *  @brief Interval is defined as the cartesian product of n 1D intervals ]low_1, up_1]x...x]low_n,up_n]
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,7 +21,6 @@
 #include "openturns/Interval.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Log.hxx"
-#include "openturns/Os.hxx"
 #include "openturns/Exception.hxx"
 #include "openturns/SpecFunc.hxx"
 #include <cmath>
@@ -186,7 +185,7 @@ Scalar Interval::computeDistance(const Point & point) const
 
   if (pointDimension != intervalDimension) throw InvalidArgumentException(HERE) << "Error: expected a point of dimension=" << pointDimension << ", got dimension=" << intervalDimension;
 
-  if (isEmpty()) return SpecFunc::MaxScalar;
+  if (isEmpty()) return SpecFunc::Infinity;
 
   Point lowerBound = getLowerBound();
   Point upperBound = getUpperBound();
@@ -417,7 +416,7 @@ void Interval::setLowerBound(const Point & lowerBound)
   for (UnsignedInteger i = 0; i < getDimension(); ++i)
     if (std::isinf(lowerBound[i]))
     {
-      lowerBound_[i] = (lowerBound[i] > 0.0 ? SpecFunc::MaxScalar : SpecFunc::LowestScalar);
+      lowerBound_[i] = (lowerBound[i] > 0.0 ? SpecFunc::Infinity : SpecFunc::LowestScalar);
       finiteLowerBound_[i] = false;
     }
 }
@@ -435,7 +434,7 @@ void Interval::setUpperBound(const Point & upperBound)
   for (UnsignedInteger i = 0; i < getDimension(); ++i)
     if (std::isinf(upperBound[i]))
     {
-      upperBound_[i] = (upperBound[i] > 0.0 ? SpecFunc::MaxScalar : SpecFunc::LowestScalar);
+      upperBound_[i] = (upperBound[i] > 0.0 ? SpecFunc::Infinity : SpecFunc::LowestScalar);
       finiteUpperBound_[i] = false;
     }
 }
@@ -491,6 +490,13 @@ String Interval::__str__(const String & offset) const
   return oss;
 }
 
+/* Is it safe to call in parallel? */
+Bool Interval::isParallel() const
+{
+  return true;
+}
+
+
 /* Method save() stores the object through the StorageManager */
 void Interval::save(Advocate & adv) const
 {
