@@ -2,7 +2,7 @@
 /**
  *  @brief Ceres solver
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,10 +22,10 @@
 #include "openturns/Point.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Log.hxx"
-#include "openturns/SpecFunc.hxx"
 #ifdef OPENTURNS_HAVE_CERES
 #include "openturns/OTwindows.h" // ceres includes windows.h
 #include <ceres/ceres.h>
+#define CERES_VERSION_NR 100000 * CERES_VERSION_MAJOR + 100 * CERES_VERSION_MINOR
 #endif
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -132,8 +132,9 @@ public:
       algorithm_.evaluationInputHistory_.add(inP);
       algorithm_.evaluationOutputHistory_.add(Point(1, 0.5 * outP.normSquare()));
     }
-    catch (Exception &)
+    catch (const Exception & exc)
     {
+      LOGWARN(OSS() << "Ceres failed to evaluate residual for x=" << inP.__str__() << " msg=" << exc.what());
       return false;
     }
 
@@ -145,8 +146,9 @@ public:
         const Matrix gradient(problem.getResidualFunction().gradient(inP));
         std::copy(gradient.data(), gradient.data() + m * n, jacobians[0]);
       }
-      catch (Exception &)
+      catch (const Exception & exc)
       {
+        LOGWARN(OSS() << "Ceres failed to evaluate residual gradient for x=" << inP.__str__() << " msg=" << exc.what());
         return false;
       }
     }
@@ -191,8 +193,9 @@ public:
       algorithm_.result_.setCallsNumber(algorithm_.evaluationInputHistory_.getSize());
       algorithm_.result_.store(inP, outP, 0.0, 0.0, 0.0, 0.0);
     }
-    catch (Exception &)
+    catch (const Exception & exc)
     {
+      LOGWARN(OSS() << "Ceres failed to evaluate objective for x=" << inP.__str__() << " msg=" << exc.what());
       return false;
     }
 
@@ -204,8 +207,9 @@ public:
         const Matrix gradient(problem.isMinimization() ? problem.getObjective().gradient(inP) : -1.0 * problem.getObjective().gradient(inP));
         std::copy(gradient.data(), gradient.data() + n, jacobian);
       }
-      catch (Exception &)
+      catch (const Exception & exc)
       {
+        LOGWARN(OSS() << "Ceres failed to evaluate objective gradient for x=" << inP.__str__() << " msg=" << exc.what());
         return false;
       }
     }
@@ -359,16 +363,26 @@ void Ceres::run()
       options.gradient_tolerance = ResourceMap::GetAsScalar("Ceres-gradient_tolerance");
     if (ResourceMap::HasKey("Ceres-parameter_tolerance"))
       options.parameter_tolerance = ResourceMap::GetAsScalar("Ceres-parameter_tolerance");
-    if (ResourceMap::HasKey("Ceres-linear_solver_type") && !ceres::StringToLinearSolverType(ResourceMap::Get("Ceres-linear_solver_type"), &options.linear_solver_type))
-      throw InvalidArgumentException(HERE) << "Invalid value for linear_solver_type";
     if (ResourceMap::HasKey("Ceres-preconditioner_type") && !ceres::StringToPreconditionerType(ResourceMap::Get("Ceres-preconditioner_type"), &options.preconditioner_type))
       throw InvalidArgumentException(HERE) << "Invalid value for preconditioner_type";
     if (ResourceMap::HasKey("Ceres-visibility_clustering_type") && !ceres::StringToVisibilityClusteringType(ResourceMap::Get("Ceres-visibility_clustering_type"), &options.visibility_clustering_type))
       throw InvalidArgumentException(HERE) << "Invalid value for visibility_clustering_type";
     if (ResourceMap::HasKey("Ceres-dense_linear_algebra_library_type") && !ceres::StringToDenseLinearAlgebraLibraryType(ResourceMap::Get("Ceres-dense_linear_algebra_library_type"), &options.dense_linear_algebra_library_type))
       throw InvalidArgumentException(HERE) << "Invalid value for dense_linear_algebra_library_type";
+
+    // prefer eigen sparse algebra backend over suitesparse
+    if (ceres::IsSparseLinearAlgebraLibraryTypeAvailable(ceres::EIGEN_SPARSE))
+      options.sparse_linear_algebra_library_type = ceres::EIGEN_SPARSE;
+    else
+    {
+      options.sparse_linear_algebra_library_type = ceres::NO_SPARSE;
+      options.linear_solver_type = ceres::DENSE_QR;
+    }
     if (ResourceMap::HasKey("Ceres-sparse_linear_algebra_library_type") && !ceres::StringToSparseLinearAlgebraLibraryType(ResourceMap::Get("Ceres-sparse_linear_algebra_library_type"), &options.sparse_linear_algebra_library_type))
       throw InvalidArgumentException(HERE) << "Invalid value for sparse_linear_algebra_library_type";
+    if (ResourceMap::HasKey("Ceres-linear_solver_type") && !ceres::StringToLinearSolverType(ResourceMap::Get("Ceres-linear_solver_type"), &options.linear_solver_type))
+      throw InvalidArgumentException(HERE) << "Invalid value for linear_solver_type";
+
     if (ResourceMap::HasKey("Ceres-use_explicit_schur_complement"))
       options.use_explicit_schur_complement = ResourceMap::GetAsBool("Ceres-use_explicit_schur_complement");
     if (ResourceMap::HasKey("Ceres-dynamic_sparsity"))
@@ -471,7 +485,13 @@ void Ceres::run()
     Pointer<IterationCallbackInterface> p_iterationCallbackInterface = new IterationCallbackInterface(*this);
     options.callbacks.push_back(p_iterationCallbackInterface.get());
     ceres::GradientProblemSolver::Summary summary;
+
+    // ceres 2.3 changed GradientProblem related APIs to use std::unique_ptr instead of raw pointers
+#if CERES_VERSION_NR < 200300
     ceres::GradientProblem problem(new FirstOrderFunctionInterface(*this));
+#else
+    ceres::GradientProblem problem(std::unique_ptr<FirstOrderFunctionInterface>(new FirstOrderFunctionInterface(*this)));
+#endif
     ceres::Solve(options, problem, &x[0], &summary);
 
     LOGINFO(OSS() << summary.BriefReport());
@@ -553,7 +573,8 @@ void Ceres::load(Advocate & adv)
 
 void Ceres::Initialize()
 {
-#ifdef OPENTURNS_HAVE_CERES
+  // ceres 2.3 switched logging library from glog to abseil
+#if defined(OPENTURNS_HAVE_CERES) && (CERES_VERSION_NR < 200300)
   google::InitGoogleLogging("openturns");
 #endif
 }
