@@ -2,7 +2,7 @@
 /**
  *  @brief OptimizationProblemImplementation allows one to describe an optimization problem
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,9 +21,7 @@
 #include <cstdlib>
 
 #include "openturns/OptimizationProblemImplementation.hxx"
-#include "openturns/ResourceMap.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
-#include "openturns/SymmetricTensor.hxx"
 #include "openturns/IdentityMatrix.hxx"
 #include "openturns/QuadraticFunction.hxx"
 #include "openturns/LinearFunction.hxx"
