@@ -2,7 +2,7 @@
 /**
  *  @brief Class for the Nataf transformation evaluation for elliptical
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,12 +20,11 @@
  */
 #include "openturns/MarginalTransformationEvaluation.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
-#include "openturns/Uniform.hxx"
 #include "openturns/Log.hxx"
 #include "openturns/ResourceMap.hxx"
 #include "openturns/SpecFunc.hxx"
 #include "openturns/SymbolicFunction.hxx"
-#include "openturns/ComposedDistribution.hxx"
+#include "openturns/JointDistribution.hxx"
 #include "openturns/Os.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -111,7 +110,7 @@ void MarginalTransformationEvaluation::initialize(const Bool simplify)
           const Scalar q75Output = outputDistribution.computeScalarQuantile(0.75);
           const Scalar a = 0.5 * (q75Output + q25Output);
           // Here, b > 0 by construction
-          const Scalar b = (q75Output - q25Output) / (q75Input - q25Input);
+          const Scalar b = (q75Input == q25Input ? 1.0 : (q75Output - q25Output) / (q75Input - q25Input));
           const Scalar c = -0.5 * (q75Input + q25Input);
           OSS oss;
           oss.setPrecision(20);
@@ -444,9 +443,9 @@ Point MarginalTransformationEvaluation::getParameter() const
 //   // else use marginals
 //   Point parameter;
 //   if (parameterSide_ & LEFT)
-//     parameter.add(ComposedDistribution(inputDistributionCollection_).getParameter());
+//     parameter.add(JointDistribution(inputDistributionCollection_).getParameter());
 //   if (parameterSide_ & RIGHT)
-//     parameter.add(ComposedDistribution(outputDistributionCollection_).getParameter());
+//     parameter.add(JointDistribution(outputDistributionCollection_).getParameter());
 //   return parameter;
 }
 
@@ -470,7 +469,7 @@ void MarginalTransformationEvaluation::setParameter(const Point & parameter)
 //       inputDistributionCollection_[i].setParameter(partialParameter);
 //       index += parametersDimension;
 //     }
-// //   index = ComposedDistribution(inputDistributionCollection_).getParameter().getDimension();
+// //   index = JointDistribution(inputDistributionCollection_).getParameter().getDimension();
 //   if ((direction_ == TO) || (direction_ == FROMTO))
 //     for (UnsignedInteger i = 0; i < getOutputDimension(); ++ i)
 //     {
@@ -494,9 +493,9 @@ Description MarginalTransformationEvaluation::getParameterDescription() const
 //   // else use marginals
 //   Description description;
 //   if (parameterSide_ & LEFT)
-//     description.add(ComposedDistribution(inputDistributionCollection_).getParameterDescription());
+//     description.add(JointDistribution(inputDistributionCollection_).getParameterDescription());
 //   if (parameterSide_ & RIGHT)
-//     description.add(ComposedDistribution(outputDistributionCollection_).getParameterDescription());
+//     description.add(JointDistribution(outputDistributionCollection_).getParameterDescription());
 //   return description;
 }
 
@@ -592,7 +591,6 @@ String MarginalTransformationEvaluation::__str__(const String & offset) const
   OSS oss(false);
   const String name(getName());
   if (hasVisibleName()) oss << "Marginal transformation " << getName() << " :" << "\n" << offset;
-  const Description inputDescription(getInputDescription());
   const Description outputDescription(getOutputDescription());
   UnsignedInteger length = 0;
   for (UnsignedInteger i = 0; i < inputDistributionCollection_.getSize(); ++i)
