@@ -31,9 +31,8 @@ Visualize sensitivity
 from openturns.usecases.ishigami_function import IshigamiModel
 import openturns as ot
 import openturns.viewer as viewer
-from matplotlib import pylab as plt
+from matplotlib import pyplot as plt
 
-ot.Log.Show(ot.Log.NONE)
 
 # %%
 # We load the :ref:`Ishigami model<use-case-ishigami>` from the `usecases` module :
