@@ -2,6 +2,7 @@
 Axial stressed beam : comparing different methods to estimate a probability
 ===========================================================================
 """
+
 # %%
 # In this example, we compare four methods to estimate the probability in the :ref:`axial stressed beam <use-case-stressed-beam>` example :
 #
@@ -22,7 +23,6 @@ from openturns.usecases import stressed_beam
 import openturns as ot
 import openturns.viewer as viewer
 
-ot.Log.Show(ot.Log.NONE)
 
 # %%
 # We load the model from the usecases module :
@@ -145,6 +145,7 @@ view = viewer.View(graph)
 algoOptim = ot.AbdoRackwitz()
 # Resolution options:
 eps = 1e-3
+algoOptim.setStartingPoint(myDistribution.getMean())
 algoOptim.setMaximumCallsNumber(1000)
 algoOptim.setMaximumAbsoluteError(eps)
 algoOptim.setMaximumRelativeError(eps)
@@ -156,15 +157,11 @@ algoOptim.setMaximumConstraintError(eps)
 initialNumberOfCall = limitStateFunction.getEvaluationCallsNumber()
 
 # %%
-# We create a FORM algorithm. The first parameter is a NearestPointAlgorithm. The second parameter is an event. The third parameter is a starting point for the design point research.
-
-# %%
-algoFORM = ot.FORM(algoOptim, myEvent, myDistribution.getMean())
+# We create a FORM algorithm. The first parameter is a NearestPointAlgorithm. The second parameter is an event.
+algoFORM = ot.FORM(algoOptim, myEvent)
 
 # %%
 # Perform the analysis.
-
-# %%
 algoFORM.run()
 
 # %%
