@@ -2,6 +2,7 @@
 Create a threshold event
 ========================
 """
+
 # %%
 # Abstract
 # --------
@@ -10,7 +11,7 @@ Create a threshold event
 #
 import openturns as ot
 import openturns.viewer as otv
-from matplotlib import pylab as plt
+from matplotlib import pyplot as plt
 
 
 # %%
