@@ -2,6 +2,7 @@
 Use the Importance Sampling algorithm
 =====================================
 """
+
 # %%
 # In this example we estimate a failure probability with the importance sampling simulation algorithm provided by the `ImportanceSamplingExperiment` class.
 #
@@ -23,7 +24,6 @@ from openturns.usecases import cantilever_beam
 import openturns as ot
 import openturns.viewer as viewer
 
-ot.Log.Show(ot.Log.NONE)
 
 # %%
 # The cantilever beam example can be accessed in the usecases module :
@@ -64,7 +64,8 @@ optimAlgo.setMaximumConstraintError(1.0e-10)
 
 # %%
 # Run FORM
-algo = ot.FORM(optimAlgo, event, distribution.getMean())
+optimAlgo.setStartingPoint(distribution.getMean())
+algo = ot.FORM(optimAlgo, event)
 algo.run()
 result = algo.getResult()
 
